/* Y o u r   D e s c r i p t i o n                       */
/*                            AppBuilder Photon Code Lib */
/*                                         Version 1.11B */

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>

/* Local headers */
#include "abimport.h"
#include "proto.h"

#define PX_IMAGE_MODULES
#define PX_BMP_SUPPORT

#include <photon/PxImage.h>

PhImage_t	*bkgd;
PhImage_t	*qnx[48];
int			seq_no = 0;

int
base_setup( PtWidget_t *link_instance, ApInfo_t *apinfo, PtCallbackInfo_t *cbinfo )

	{
	int				i;
	char			fname[PATH_MAX];
	PxMethods_t		methods;
	PtArg_t			args[1];

	/* eliminate 'unreferenced' warnings */
	link_instance = link_instance, apinfo = apinfo, cbinfo = cbinfo;
	
	memset( &methods, 0, sizeof( methods ) );
	methods.px_alloc = base_allocate;
    methods.flags   |= PX_LOAD;

	if ( NULL == ( bkgd = PxLoadImage( "/usr/photon/qnx96/toronto.bmp", &methods ) ) ) {
		printf( "qnx96: error loading background image\n" );
		exit( EXIT_FAILURE );
		}
	
    for ( i = 0; i < 48; i++ ) {
		sprintf( fname, "/usr/photon/qnx96/qnx96%02d.bmp", i + 1 );
		if ( NULL == ( qnx[i] = PxLoadImage( fname, &methods ) ) ) {
			printf( "qnx96: error loading image qnx96%02d.bmp\n", i + 1 );
			exit( EXIT_FAILURE );
			}
		}

	/* draw the background */
	PtSetArg( &args[0], Pt_ARG_LABEL_DATA, bkgd, sizeof( PhImage_t ) );
	PtSetResources( ABW_toronto, 1, args );

	/* start the timer */
	PtSetArg( &args[0], Pt_ARG_TIMER_INITIAL, 50, 0 );	
	PtSetResources( ABW_base_timer, 1, args );

	signal( SIGINT,  base_signal );
	signal( SIGTERM, base_signal );
	signal( SIGHUP,  base_signal );

	return( Pt_CONTINUE );
	}

void
base_signal( int sig_no )

	{

	/* clean-up shared memory */
	PgShmemCleanup( );
	exit( EXIT_SUCCESS );

	}

int
base_animate( PtWidget_t *widget, ApInfo_t *apinfo, PtCallbackInfo_t *cbinfo )

	{
	PtArg_t		args[1];

	/* eliminate 'unreferenced' warnings */
	widget = widget, apinfo = apinfo, cbinfo = cbinfo;

	PtSetArg( &args[0], Pt_ARG_LABEL_DATA, qnx[seq_no++], sizeof( PhImage_t ) );
	PtSetResources( ABW_qnx96, 1, args );
	PtFlush( );

	/* re-cycle at 48 */
	if ( seq_no == 48 )
		seq_no = 0;

	return( Pt_CONTINUE );
	}

void *
base_allocate( long nbytes, int type ) 

	{

	if ( type == PX_IMAGE )
		return( PgShmemCreate( nbytes, NULL ) );
	else
		return( calloc( 1, nbytes ) );

	}
